pub struct ImageDesc {
pub size: [u32; 2],
pub premultiplied: bool,
pub mips: bool,
}Expand description
ImageDesc describes an RGBA8 image upload.
Fields
size: [u32; 2]size is the image dimensions in pixels.
premultiplied: boolpremultiplied indicates whether the supplied RGB channels already
contain alpha multiplication.
When false, Valo premultiplies them during upload.
mips: boolmips controls whether Valo builds a full mip chain.
Enable it when the image may be drawn smaller than its source size.