RenderTarget

Struct RenderTarget 

pub struct RenderTarget<'a> {
    pub view: &'a TextureView,
    pub texture: &'a Texture,
    pub format: TextureFormat,
    pub size: [u32; 2],
    pub clear: Option<Color>,
}
RenderTarget is the destination for one render operation.

texture must be the resource behind view and match format and size. Advanced blends and backdrop filters require COPY_SRC texture usage.

Fields

view: &'a TextureView

view is the attachment into which Valo renders.

texture: &'a Texture

texture is the resource behind view.

format: TextureFormat

format is the pixel format exposed by view.

size: [u32; 2]

size is the renderable area in pixels.

clear: Option<Color>

clear replaces existing pixels when set and preserves them when None.